@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atiprint.c,v 1.27 2003/09/24 02:43:18 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atiprint.c,v 1.28 2003/11/07 13:45:26 tsi Exp $ */
 /*
  * Copyright 1997 through 2003 by Marc Aurele La France (TSI @ UQV), tsi@xfree86.org
  *
@@ -184,7 +184,7 @@ ATIMach64PrintRegisters
                 (IOValue & CRTC_EXT_DISP_EN))
                 *crtc = ATI_CRTC_MACH64;
 
-            xf86ErrorFVerb(4, " %08X", IOValue);
+            xf86ErrorFVerb(4, " %08lX", (unsigned long)IOValue);
         }
     }
 
