@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis.h,v 1.81 2003/10/31 19:58:59 twini Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis.h,v 1.99 2003/12/16 17:45:19 twini Exp $ */
 /*
  * Main global data and definitions
  *
@@ -24,8 +24,8 @@
  *
  * Authors:
  *
- *      ?
  *      Thomas Winischhofer <thomas@winischhofer.net>
+ *      ?
  *
  */
 #ifndef _SIS_H
@@ -35,8 +35,8 @@
 #define UNLOCK_ALWAYS
 
 #define SISDRIVERVERSIONYEAR    3
-#define SISDRIVERVERSIONMONTH   10
-#define SISDRIVERVERSIONDAY     31
+#define SISDRIVERVERSIONMONTH   12
+#define SISDRIVERVERSIONDAY     15
 #define SISDRIVERREVISION       1
 
 #define SISDRIVERIVERSION (SISDRIVERVERSIONYEAR << 16) | (SISDRIVERVERSIONMONTH << 8) \
@@ -67,8 +67,12 @@
 
 #ifdef XF86DRI
 #undef SISNEWDRI
+#undef SISNEWDRI2
 #if XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(4,3,99,14,0)
 #define SISNEWDRI
+#if XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(4,4,99,99,0)	/* Adapt this when the time has come */
+#define SISNEWDRI2
+#endif
 #endif
 #include "xf86drm.h"
 #include "sarea.h"
@@ -177,9 +181,9 @@
 #define DISPTYPE_DISP2		CRT2_ENABLE
 #define TV_NTSC                 0x00000010
 #define TV_PAL                  0x00000020
-#define TV_HIVISION             0x00000040
-#define TV_HIVISION_LV          0x00000080
-#define TV_TYPE                 (TV_NTSC | TV_PAL | TV_HIVISION | TV_HIVISION_LV)
+#define TV_HIVISION             0x00000040 /* Not supported */
+#define TV_YPBPR                0x00000080 /* Not supported */
+#define TV_TYPE                 (TV_NTSC | TV_PAL | TV_HIVISION | TV_YPBPR)
 #define TV_AVIDEO               0x00000100
 #define TV_SVIDEO               0x00000200
 #define TV_SCART                0x00000400
@@ -188,7 +192,7 @@
 #define TV_PALM                 0x00001000
 #define TV_PALN                 0x00002000
 #define TV_NTSCJ		0x00001000
-#define VB_301LVX		0x00004000
+#define VB_302ELV		0x00004000
 #define TV_CHSCART              0x00008000
 #define TV_CHHDTV               0x00010000
 #define CRT1_VGA		0x00000000
@@ -205,9 +209,9 @@
 #define VB_301LV                0x04000000
 #define VB_302LV                0x08000000
 #define VB_301C			0x10000000
-#define VB_VIDEOBRIDGE		(VB_301|VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_301LVX| \
-				 VB_LVDS|VB_CHRONTEL|VB_CONEXANT)
-#define VB_SISBRIDGE            (VB_301|VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_301LVX)
+#define VB_SISBRIDGE            (VB_301|VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_302ELV)
+#define VB_SISTVBRIDGE          (VB_301|VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV)
+#define VB_VIDEOBRIDGE		(VB_SISBRIDGE|VB_LVDS|VB_CHRONTEL|VB_CONEXANT)
 #define SINGLE_MODE             0x20000000   	/* CRT1 or CRT2; determined by DISPTYPE_CRTx */
 #define VB_DISPMODE_SINGLE	SINGLE_MODE  	/* alias */
 #define MIRROR_MODE		0x40000000   	/* CRT1 + CRT2 identical (mirror mode) */
@@ -245,6 +249,7 @@
 /* pSiS->MiscFlags */
 #define MISC_CRT1OVERLAY	0x00000001  /* Current display mode supports overlay */
 #define MISC_PANELLINKSCALER    0x00000002  /* Panel link is currently scaling */
+#define MISC_CRT1OVERLAYGAMMA	0x00000004  /* Current display mode supports overlay gamma corr on CRT1 */
 
 /* SiS6326Flags */
 #define SIS6326_HASTV		0x00000001
@@ -341,6 +346,8 @@ typedef unsigned char UChar;
 #define SiS_SD_SUPPORTVGA2     0x00040000   /* CRT2=VGA supported */
 #define SiS_SD_SUPPORTSCART    0x00080000   /* CRT2=SCART supported */
 #define SiS_SD_SUPPORTOVERSCAN 0x00100000   /* Overscan flag supported */
+#define SiS_SD_SUPPORTXVGAMMA1 0x00200000   /* Xv Gamma correction for CRT1 supported */
+#define SiS_SD_SUPPORTTV       0x00400000   /* CRT2=TV supported */
 
 #define SIS_DIRECTKEY         0x03145792
 
@@ -354,6 +361,16 @@ typedef unsigned char UChar;
 #define SiS_CF2_TVPALN     0x40
 #define SiS_CF2_CRT1LCDA   0x80
 
+/* AGP stuff for DRI */
+#define AGP_PAGE_SIZE 4096
+#define AGP_PAGES     2048	 /* Default: 2048 pages @ 4096 = 8MB */
+/* 300 */
+#define AGP_CMDBUF_PAGES 256
+#define AGP_CMDBUF_SIZE (AGP_PAGE_SIZE * AGP_CMDBUF_PAGES)
+/* 315/330 */
+#define AGP_VTXBUF_PAGES 512
+#define AGP_VTXBUF_SIZE (AGP_PAGE_SIZE * AGP_VTXBUF_PAGES)
+
 /* For backup of register contents */
 typedef struct {
     unsigned char sisRegs3C4[0x50];
@@ -362,7 +379,7 @@ typedef struct {
     unsigned char sisCapt[0x60];
     unsigned char sisVid[0x50];
     unsigned char VBPart1[0x50];
-    unsigned char VBPart2[0x50];
+    unsigned char VBPart2[0x100];
     unsigned char VBPart3[0x50];
     unsigned char VBPart4[0x50];
     unsigned short ch70xx[64];
@@ -403,6 +420,8 @@ typedef struct {
     unsigned long	agpAddr;
     unsigned char 	*agpBase;
     unsigned int 	agpSize;
+    unsigned int        agpWantedSize;
+    unsigned int        agpWantedPages;
     unsigned long	agpCmdBufAddr;  /* 300 series */
     unsigned char 	*agpCmdBufBase;
     unsigned int 	agpCmdBufSize;
@@ -420,6 +439,7 @@ typedef struct {
     DisplayModePtr	CRT1DMode;		/* Current display mode for CRT1 */
     int 		CRT2ModeNo;		/* Current display mode for CRT2 */
     DisplayModePtr	CRT2DMode;		/* Current display mode for CRT2 */
+    Bool		CRT2ModeSet;		/* CRT2 mode has been set */
     Bool		CRT2IsCustom;
     unsigned char	CRT2CR30, CRT2CR31, CRT2CR35, CRT2CR38;
     int			refCount;
@@ -435,7 +455,6 @@ typedef struct {
     int			OptTVSOver;
     int                 OptROMUsage;
     int			OptUseOEM;
-    int                 PDC;
     Bool                NoAccel;
     int			forceCRT1;
     int			DSTN, FSTN;
@@ -485,13 +504,19 @@ typedef struct {
     unsigned char       scalingp1[9], scalingp4[9];
     unsigned short      cursorBufferNum;
     BOOLEAN		restorebyset;
-    BOOLEAN		CRT1gamma, CRT2gamma;
+    BOOLEAN		CRT1gamma, CRT1gammaGiven, CRT2gamma, XvGamma, XvGammaGiven;
+    int			XvGammaRed, XvGammaGreen, XvGammaBlue;
+    int			GammaBriR, GammaBriG, GammaBriB;	/* strictly for Xinerama */
+    int			GammaPBriR, GammaPBriG, GammaPBriB;	/* strictly for Xinerama */
     int			curxvcrtnum;
     int			UsePanelScaler;
     int			AllowHotkey;
     BOOLEAN		enablesisctrl;
     unsigned long	cmdQ_SharedWritePort_2D;
     unsigned char       *RenderAccelArray;
+    unsigned char *	FbBase1;
+    unsigned long	OnScreenSize1;
+    unsigned char       OldMode;
 #ifdef SIS_CP
     SIS_CP_H_ENT
 #endif
@@ -568,7 +593,8 @@ typedef struct {
     int			forceCRT1;
     Bool		CRT1changed;
     unsigned char       oldCR17, oldCR63, oldSR1F;
-    unsigned char       oldCR32;
+    unsigned char       oldCR32, oldCR36, oldCR37;
+    unsigned char       myCR32, myCR36, myCR37;
     unsigned char       newCR32;
     unsigned long   	VBFlags;		/* Video bridge configuration */
     unsigned long       VBFlags_backup;         /* Backup for SlaveMode-modes */
@@ -635,6 +661,8 @@ typedef struct {
     unsigned long	agpAddr;
     unsigned char 	*agpBase;
     unsigned int 	agpSize;
+    unsigned int        agpWantedSize;
+    unsigned int        agpWantedPages;
     unsigned long	agpCmdBufAddr;  /* 300 series */
     unsigned char 	*agpCmdBufBase;
     unsigned int 	agpCmdBufSize;
@@ -692,6 +720,7 @@ typedef struct {
     ScreenBlockHandlerProcPtr BlockHandler;
     void                (*VideoTimerCallback)(ScrnInfoPtr, Time);
     void		(*ResetXv)(ScrnInfoPtr);
+    void		(*ResetXvGamma)(ScrnInfoPtr);
 
     OptionInfoPtr 	Options;
     unsigned char 	LCDon;
@@ -768,6 +797,9 @@ typedef struct {
     unsigned char       sisfblcda;
     int			sisfbscalelcd;
     unsigned long	sisfbspecialtiming;
+    BOOL		sisfb_haveemi, sisfb_haveemilcd;
+    unsigned char	sisfb_emi30,sisfb_emi31,sisfb_emi32,sisfb_emi33;
+    int			EMI;
     int			NoYV12;			/* Disable Xv YV12 support (old series) */
     unsigned char       postVBCR32;
     int			newFastVram;		/* Replaces FastVram */
@@ -792,10 +824,12 @@ typedef struct {
     Atom		xvDisableGfx, xvDisableGfxLR, xvTVXPosition, xvTVYPosition;
     Atom		xvDisableColorkey, xvUseChromakey, xvChromaMin, xvChromaMax;
     Atom		xvInsideChromakey, xvYUVChromakey;
+    Atom		xvGammaRed, xvGammaGreen, xvGammaBlue;
     Atom		xv_QVF, xv_QVV, xv_USD, xv_SVF, xv_QDD, xv_TAF, xv_TSA, xv_TEE, xv_GSF;
     Atom		xv_TTE, xv_TCO, xv_TCC, xv_TCF, xv_TLF, xv_CMD, xv_CMDR, xv_CT1, xv_SGA;
     Atom		xv_GDV, xv_GHI, xv_OVR, xv_GBI, xv_TXS, xv_TYS, xv_CFI, xv_COC, xv_COF;
     Atom		xv_YFI, xv_GSS, xv_BRR, xv_BRG, xv_BRB, xv_PBR, xv_PBG, xv_PBB, xv_SHC;
+    Atom		xv_BRR2, xv_BRG2, xv_BRB2, xv_PBR2, xv_PBG2, xv_PBB2;
 #ifdef TWDEBUG
     Atom		xv_STR;
 #endif        
@@ -816,13 +850,16 @@ typedef struct {
     BOOLEAN		restorebyset;
     BOOLEAN		nocrt2ddcdetection;
     BOOLEAN		forcecrt2redetection;
-    BOOLEAN		CRT1gamma, CRT2gamma;
+    BOOLEAN		CRT1gamma, CRT1gammaGiven, CRT2gamma, XvGamma, XvGammaGiven;
     int			XvDefCon, XvDefBri, XvDefHue, XvDefSat;
     BOOLEAN		XvDefDisableGfx, XvDefDisableGfxLR;
     BOOLEAN		XvUseMemcpy;
     BOOLEAN		XvUseChromaKey, XvDisableColorKey;
     BOOLEAN		XvInsideChromaKey, XvYUVChromaKey;
     int			XvChromaMin, XvChromaMax;
+    int			XvGammaRed, XvGammaGreen, XvGammaBlue;
+    int			XvGammaRedDef, XvGammaGreenDef, XvGammaBlueDef;
+    CARD8		XvGammaRampRed[256], XvGammaRampGreen[256], XvGammaRampBlue[256];
     BOOLEAN		disablecolorkeycurrent;
     CARD32		colorKey;
     CARD32		MiscFlags;
@@ -1027,7 +1064,7 @@ extern void  SiS_SetTVyposoffset(ScrnInfoPtr pScrn, int val);
 extern void  SiS_SetTVxscale(ScrnInfoPtr pScrn, int val);
 extern void  SiS_SetTVyscale(ScrnInfoPtr pScrn, int val);
 extern Bool  SISSwitchCRT2Type(ScrnInfoPtr pScrn, unsigned long newvbflags);
-extern Bool  SISCheckModeIndexForCRT2Type(ScrnInfoPtr pScrn, unsigned short cond,
+extern int   SISCheckModeIndexForCRT2Type(ScrnInfoPtr pScrn, unsigned short cond,
 					  unsigned short index, Bool quiet);
 extern Bool  SISSwitchCRT1Status(ScrnInfoPtr pScrn, int onoff);
 extern int   SiS_GetCHTVlumabandwidthcvbs(ScrnInfoPtr pScrn);
