@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis_dac.c,v 1.44 2003/10/30 18:53:42 twini Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis_dac.c,v 1.51 2003/11/30 22:29:52 twini Exp $ */
 /*
  * DAC helper functions (Save/Restore, MemClk, etc)
  *
@@ -186,15 +186,18 @@ SiSCalcClock(ScrnInfoPtr pScrn, int clock, int max_VLD, unsigned int *vclk)
     SISPtr pSiS = SISPTR(pScrn);
     int M, N, P , PSN, VLD , PSNx ;
     int bestM=0, bestN=0, bestP=0, bestPSN=0, bestVLD=0;
-    double bestError, abest = 42.0, bestFout;
+    double abest = 42.0;
     double target;
     double Fvco, Fout;
     double error, aerror;
+#ifdef DEBUG
+    double bestFout;
+#endif
 
     /*
      *  fd = fref*(Numerator/Denumerator)*(Divider/PostScaler)
      *
-     *  M       = Numerator [1:128] 
+     *  M       = Numerator [1:128]
      *  N       = DeNumerator [1:32]
      *  VLD     = Divider (Vco Loop Divider) : divide by 1, 2
      *  P       = Post Scaler : divide by 1, 2, 3, 4
@@ -255,13 +258,14 @@ SiSCalcClock(ScrnInfoPtr pScrn, int clock, int max_VLD, unsigned int *vclk)
          aerror = (error < 0) ? -error : error;
          if(aerror < abest) {
             abest = aerror;
-            bestError = error;
             bestM = M;
             bestN = N;
             bestP = P;
             bestPSN = PSN;
             bestVLD = VLD;
+#ifdef DEBUG
             bestFout = Fout;
+#endif	    
          }
      }
 
@@ -311,13 +315,14 @@ SiSCalcClock(ScrnInfoPtr pScrn, int clock, int max_VLD, unsigned int *vclk)
                     aerror = (error < 0) ? -error : error;
                     if(aerror < abest) {
                        abest = aerror;
-                       bestError = error;
                        bestM = M;
                        bestN = N;
                        bestP = P;
                        bestPSN = PSN;
                        bestVLD = VLD;
+#ifdef DEBUG
                        bestFout = Fout;
+#endif
                     }
 #ifdef TWDEBUG
                     xf86DrvMsgVerb(pScrn->scrnIndex, X_INFO,3,
@@ -545,7 +550,7 @@ SiS300Save(ScrnInfoPtr pScrn, SISRegPtr sisReg)
           (*pSiS->SiSSaveLVDSChrontel)(pScrn, sisReg);
        if(pSiS->VBFlags & VB_301)
           (*pSiS->SiSSave2)(pScrn, sisReg);
-       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV))
+       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_302ELV))
           (*pSiS->SiSSave3)(pScrn, sisReg);
 #ifndef TWDEBUG
     }
@@ -698,7 +703,7 @@ SiS300Restore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
           (*pSiS->SiSRestoreLVDSChrontel)(pScrn, sisReg);
        if(pSiS->VBFlags & VB_301)
           (*pSiS->SiSRestore2)(pScrn, sisReg);
-       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV))
+       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_302ELV))
           (*pSiS->SiSRestore3)(pScrn, sisReg);
     }
 
@@ -777,7 +782,7 @@ SiS315Save(ScrnInfoPtr pScrn, SISRegPtr sisReg)
           (*pSiS->SiSSaveLVDSChrontel)(pScrn, sisReg);
        if(pSiS->VBFlags & VB_301)
           (*pSiS->SiSSave2)(pScrn, sisReg);
-       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV))
+       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_302ELV))
           (*pSiS->SiSSave3)(pScrn, sisReg);
 #ifndef TWDEBUG
     }
@@ -892,7 +897,7 @@ SiS315Restore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
           (*pSiS->SiSRestoreLVDSChrontel)(pScrn, sisReg);
        if(pSiS->VBFlags & VB_301)
           (*pSiS->SiSRestore2)(pScrn, sisReg);
-       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV))
+       if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_302ELV))
           (*pSiS->SiSRestore3)(pScrn, sisReg);
     }
 
@@ -1032,13 +1037,14 @@ SiS301BSave(ScrnInfoPtr pScrn, SISRegPtr sisReg)
     SISPtr  pSiS = SISPTR(pScrn);
     int     Part1max, Part2max, Part3max, Part4max;
 
-    Part1max = 0x37; /* 0x23, but we also need 2c-2e, 35-37 */
+    Part1max = 0x4c;
     Part2max = 0x4d;
     Part3max = 0x3e;
-    if(pSiS->VBFlags & (VB_301LV|VB_302LV))
+    Part4max = 0x23;
+    if(pSiS->VBFlags & (VB_301C|VB_302ELV))
+       Part2max = 0xff;
+    if(pSiS->VBFlags & (VB_301C|VB_301LV|VB_302LV|VB_302ELV))
        Part4max = 0x34;
-    else
-       Part4max = 0x23;
 
     SiSVBSave(pScrn, sisReg, Part1max, Part2max, Part3max, Part4max);
 
@@ -1056,10 +1062,11 @@ SiS301BRestore(ScrnInfoPtr pScrn, SISRegPtr sisReg)
     Part1max = 0x23;
     Part2max = 0x4d;
     Part3max = 0x3e;
-    if(pSiS->VBFlags & (VB_301LV|VB_302LV))
+    Part4max = 0x22;
+    if(pSiS->VBFlags & (VB_301C|VB_302ELV))
+       Part2max = 0xff;
+    if(pSiS->VBFlags & (VB_301LV|VB_302LV|VB_302ELV))
        Part4max = 0x24;
-    else
-       Part4max = 0x22;
 
     SiS_DisableBridge(pSiS->SiS_Pr, &pSiS->sishw_ext);
 
@@ -1388,7 +1395,7 @@ SiSMclk(SISPtr pSiS)
  * For VGA2, we share the bandwith equally.
  */
 static int
-SiSEstimateCRT2Clock(ScrnInfoPtr pScrn)
+SiSEstimateCRT2Clock(ScrnInfoPtr pScrn, BOOLEAN IsForMergedFBCRT2)
 {
         SISPtr pSiS = SISPTR(pScrn);
 
@@ -1399,7 +1406,11 @@ SiSEstimateCRT2Clock(ScrnInfoPtr pScrn)
 	      return 65000;
 	   else if(pSiS->VBLCDFlags & VB_LCD_1280x768)
 	      return 81000;
-	   else if(pSiS->VBLCDFlags & (VB_LCD_1280x1024 | VB_LCD_1280x960 | VB_LCD_1400x1050))
+	   else if(pSiS->VBLCDFlags & VB_LCD_1400x1050) {
+	      /* Must fake clock; built-in mode shows 122 for VGA, but uses only 108 for LCD */
+	      if(IsForMergedFBCRT2) return 123000;
+	      else                  return 108000;
+	   } else if(pSiS->VBLCDFlags & (VB_LCD_1280x1024 | VB_LCD_1280x960))
 	      return 108000;
 	   else if(pSiS->VBLCDFlags & VB_LCD_1600x1200)
 	      return 162000;
@@ -1527,11 +1538,13 @@ int SiSMemBandWidth(ScrnInfoPtr pScrn, BOOLEAN IsForCRT2)
 
 		    maxcrt2 = 135000;
 		    if(pSiS->VBFlags & (VB_301B|VB_302B)) maxcrt2 = 162000;
-		    else if(pSiS->VBFlags & VB_301C)      maxcrt2 = 162000;  /* ? */
-		    if(pSiS->VBFlags & VB_30xBDH)         maxcrt2 = 100000;
+		    else if(pSiS->VBFlags & VB_301C)      maxcrt2 = 203000;
+		    /* if(pSiS->VBFlags & VB_30xBDH)      maxcrt2 = 100000;
+		       Ignore 301B-DH here; seems the current version is like
+		       301B anyway */
 
 		    crt2used = 0.0;
-		    crt2clock = SiSEstimateCRT2Clock(pScrn);
+		    crt2clock = SiSEstimateCRT2Clock(pScrn, IsForCRT2);
 		    if(crt2clock) {
 		    	crt2used = crt2clock + 2000;
 		    }
@@ -1591,7 +1604,6 @@ int SiSMemBandWidth(ScrnInfoPtr pScrn, BOOLEAN IsForCRT2)
 				      crt2used/1000);
 
 			} else {
-
 #ifdef SISDUALHEAD
 			     /* TW: Second head = CRT1 */
 
@@ -1636,9 +1648,8 @@ int SiSMemBandWidth(ScrnInfoPtr pScrn, BOOLEAN IsForCRT2)
 
 			xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
 			  "Bandwidth available for CRT1 is %g MHz\n", total/1000);
-#ifdef SISDUALHEAD
+
                     }
-#endif
 
                 }
 		total /= magic;
@@ -1664,7 +1675,9 @@ SISLoadPalette(ScrnInfoPtr pScrn, int numColors, int *indices, LOCO *colors,
 {
      SISPtr  pSiS = SISPTR(pScrn);
      int     i, j, index;
+     unsigned char backup = 0;
      Bool    dogamma1 = pSiS->CRT1gamma;
+     Bool    resetxvgamma = FALSE;
 #ifdef SISDUALHEAD
      SISEntPtr pSiSEnt = pSiS->entityPrivate;
 
@@ -1674,10 +1687,21 @@ SISLoadPalette(ScrnInfoPtr pScrn, int numColors, int *indices, LOCO *colors,
      PDEBUG(ErrorF("SiSLoadPalette(%d)\n", numColors));
 
 #ifdef SISDUALHEAD
-     if( ((pSiS->DualHeadMode) && (pSiS->SecondHead)) ||
-         (!pSiS->DualHeadMode) ) {
+     if((!pSiS->DualHeadMode) || (pSiS->SecondHead)) {
 #endif
 
+        if(pSiS->VGAEngine == SIS_315_VGA) {
+	   inSISIDXREG(SISSR, 0x1f, backup);
+	   andSISIDXREG(SISSR, 0x1f, 0xe7);
+	   if( (pSiS->XvGamma) &&
+	       (pSiS->MiscFlags & MISC_CRT1OVERLAYGAMMA) &&
+	       ((pSiS->CurrentLayout.depth == 16) ||
+	        (pSiS->CurrentLayout.depth == 24)) ) {
+	      orSISIDXREG(SISSR, 0x1f, 0x10);
+	      resetxvgamma = TRUE;
+	   }
+        }
+
         switch(pSiS->CurrentLayout.depth) {
 #ifdef SISGAMMA
           case 15:
@@ -1747,25 +1771,30 @@ SISLoadPalette(ScrnInfoPtr pScrn, int numColors, int *indices, LOCO *colors,
              }
 	}
 
+	if(pSiS->VGAEngine == SIS_315_VGA) {
+	   outSISIDXREG(SISSR, 0x1f, backup);
+	   inSISIDXREG(SISSR, 0x07, backup);
+	   if((backup & 0x04) && (resetxvgamma) && (pSiS->ResetXvGamma)) {
+	      (pSiS->ResetXvGamma)(pScrn);
+	   }
+	}
+
 #ifdef SISDUALHEAD		
     }	
 
-    if( ((pSiS->DualHeadMode) && (!pSiS->SecondHead)) ||
-         (!pSiS->DualHeadMode) ) {
+    if((!pSiS->DualHeadMode) || (!pSiS->SecondHead)) {
 #endif
 
-        switch(pSiS->VGAEngine) {
-            case SIS_300_VGA:
-            case SIS_315_VGA:
-                if(pSiS->VBFlags & CRT2_ENABLE) {
-		    /* TW: Only the SiS bridges support a CRT2 palette */
-		    if(pSiS->VBFlags & VB_SISBRIDGE) {
-                        (*pSiS->LoadCRT2Palette)(pScrn, numColors, indices,
-                                                 colors, pVisual);
-		    }  
-                }
-                break;
-        }
+       switch(pSiS->VGAEngine) {
+       case SIS_300_VGA:
+       case SIS_315_VGA:
+          if(pSiS->VBFlags & CRT2_ENABLE) {
+	     /* Only the SiS bridges support a CRT2 palette */
+	     if(pSiS->VBFlags & VB_SISBRIDGE) {
+                (*pSiS->LoadCRT2Palette)(pScrn, numColors, indices, colors, pVisual);
+	     }
+          }
+       }
 	
 #ifdef SISDUALHEAD		
     }
