@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis_dri.c,v 1.35 2003/10/30 18:53:42 twini Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis_dri.c,v 1.39 2003/11/20 19:53:23 twini Exp $ */
 /*
  *  DRI wrapper for 300 and 315 series
  *
@@ -21,7 +21,6 @@
 #include "GL/glxtokens.h"
 
 #include "sis.h"
-#include "sis_dri.h"
 #if XF86_VERSION_CURRENT >= XF86_VERSION_NUMERIC(4,2,99,0,0)
 #include "xf86drmCompat.h"
 #endif
@@ -52,16 +51,6 @@ extern void GlxSetVisualConfigs(
     void **configprivs
 );
 
-#define AGP_PAGE_SIZE 4096
-#define AGP_PAGES 2048
-#define AGP_SIZE (AGP_PAGE_SIZE * AGP_PAGES)
-#define AGP_CMDBUF_PAGES 256
-#define AGP_CMDBUF_SIZE (AGP_PAGE_SIZE * AGP_CMDBUF_PAGES)
-
-/* 315/330 */
-#define AGP_VTXBUF_PAGES 512
-#define AGP_VTXBUF_SIZE (AGP_PAGE_SIZE * AGP_VTXBUF_PAGES)
-
 static char SISKernelDriverName[] = "sis";
 static char SISClientDriverName[] = "sis";
 
@@ -187,7 +176,7 @@ SISInitVisualConfigs(ScreenPtr pScreen)
     }
     if(i != numConfigs) {
        xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
-                 "[dri] Incorrect initialization of visuals.  Disabling DRI.\n");
+                 "[dri] Incorrect initialization of visuals. Disabling DRI.\n");
        return FALSE;
     }
     break;
@@ -217,7 +206,8 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
 #endif
 
    /* Check that the GLX, DRI, and DRM modules have been loaded by testing
-    * for canonical symbols in each module. */
+    * for canonical symbols in each module.
+    */
    if(!xf86LoaderCheckSymbol("GlxSetVisualConfigs")) return FALSE;
    if(!xf86LoaderCheckSymbol("DRIScreenInit"))       return FALSE;
    if(!xf86LoaderCheckSymbol("drmAvailable"))        return FALSE;
@@ -234,8 +224,8 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
       if(major != 4 || minor < 0) {
          xf86DrvMsg(pScreen->myNum, X_ERROR,
                     "[dri] SISDRIScreenInit failed because of a version mismatch.\n"
-                    "[dri] libDRI version is %d.%d.%d but version 4.0.x is needed.\n"
-                    "[dri] Disabling DRI.\n",
+                    "\t[dri] libDRI version is %d.%d.%d but version 4.0.x is needed.\n"
+                    "\t[dri] Disabling DRI.\n",
                     major, minor, patch);
          return FALSE;
       }
@@ -247,11 +237,20 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
 
   pDRIInfo->drmDriverName = SISKernelDriverName;
   pDRIInfo->clientDriverName = SISClientDriverName;
-  pDRIInfo->busIdString = xalloc(64);
-  sprintf(pDRIInfo->busIdString, "PCI:%d:%d:%d",
-      	((pciConfigPtr)pSIS->PciInfo->thisCard)->busnum,
-      	((pciConfigPtr)pSIS->PciInfo->thisCard)->devnum,
-      	((pciConfigPtr)pSIS->PciInfo->thisCard)->funcnum);
+#ifdef SISNEWDRI2
+  if(xf86LoaderCheckSymbol("DRICreatePCIBusID")) {
+     pDRIInfo->busIdString = DRICreatePCIBusID(pSiS->PciInfo);
+  } else {
+#endif
+     pDRIInfo->busIdString = xalloc(64);
+     sprintf(pDRIInfo->busIdString, "PCI:%d:%d:%d",
+             ((pciConfigPtr)pSIS->PciInfo->thisCard)->busnum,
+      	     ((pciConfigPtr)pSIS->PciInfo->thisCard)->devnum,
+      	     ((pciConfigPtr)pSIS->PciInfo->thisCard)->funcnum);
+#ifdef SISNEWDRI2
+  }
+#endif
+
   /* Hack to keep old DRI working -- checked for major==1 and
    * minor==1.
    */
@@ -325,7 +324,7 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
 
   if(!DRIScreenInit(pScreen, pDRIInfo, &pSIS->drmSubFD)) {
      xf86DrvMsg(pScreen->myNum, X_ERROR,
-               "[dri] DRIScreenInit failed.  Disabling DRI.\n");
+               "[dri] DRIScreenInit failed. Disabling DRI.\n");
      xfree(pDRIInfo->devPrivate);
      pDRIInfo->devPrivate = 0;
      DRIDestroyInfoRec(pSIS->pDRIInfo);
@@ -359,9 +358,9 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
       fb.size = pSIS->DRIheapend - pSIS->DRIheapstart;
       drmCommandWrite(pSIS->drmSubFD, DRM_SIS_FB_INIT, &fb, sizeof(fb));
       xf86DrvMsg(pScreen->myNum, X_INFO,
-                 "[dri] DRI video RAM memory heap: 0x%x to 0x%x (%dKB)\n",
+                 "[dri] DRI video RAM memory heap: 0x%lx to 0x%lx (%dKB)\n",
                  pSIS->DRIheapstart, pSIS->DRIheapend,
-                 (pSIS->DRIheapend - pSIS->DRIheapstart) >> 10);
+                 (int)((pSIS->DRIheapend - pSIS->DRIheapstart) >> 10));
     }
     drmFreeVersion(version);
   }
@@ -381,15 +380,16 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
 
   /* AGP */
   do {
+    pSIS->agpWantedSize = pSIS->agpWantedPages * AGP_PAGE_SIZE;
     pSIS->agpSize = 0;
     pSIS->agpCmdBufSize = 0;
     pSISDRI->AGPCmdBufSize = 0;
 
     if(!pSIS->IsAGPCard)
        break;
-    
+
     if(drmAgpAcquire(pSIS->drmSubFD) < 0) {
-       xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] drmAgpAcquire failed\n");
+       xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to acquire AGP, AGP disabled\n");
        break;
     }
 
@@ -397,43 +397,76 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
 #ifdef SIS315DRI
        /* Default to 1X agp mode in SIS315 */
        if(drmAgpEnable(pSIS->drmSubFD, drmAgpGetMode(pSIS->drmSubFD) & ~0x00000002) < 0) {
-          xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] drmAgpEnable failed\n");
+          xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to enable AGP, AGP disabled\n");
           break;
        }
 #endif
     } else {
        /* TODO: default value is 2x? */
        if(drmAgpEnable(pSIS->drmSubFD, drmAgpGetMode(pSIS->drmSubFD) & ~0x0) < 0) {
-          xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] drmAgpEnable failed\n");
+          xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to enable AGP, AGP disabled\n");
           break;
        }
     }
 
-    xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] drmAgpEnabled succeeded\n");
+    xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] AGP enabled\n");
 
-    if(drmAgpAlloc(pSIS->drmSubFD, AGP_SIZE, 0, NULL, &pSIS->agpHandle) < 0) {
-       xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] drmAgpAlloc failed\n");
-       drmAgpRelease(pSIS->drmSubFD);
-       break;
+#define AGP_DEFAULT_SIZE_MB 8
+#define AGP_DEFAULT_SIZE    (AGP_DEFAULT_SIZE_MB * 1024 * 1024)
+
+    if(drmAgpAlloc(pSIS->drmSubFD, pSIS->agpWantedSize, 0, NULL, &pSIS->agpHandle) < 0) {
+       xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to allocate %dMB AGP memory\n",
+                  (int)(pSIS->agpWantedSize / (1024 * 1024)));
+       if(pSIS->agpWantedSize > AGP_DEFAULT_SIZE) {
+          xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Retrying with %dMB\n", AGP_DEFAULT_SIZE_MB);
+          pSIS->agpWantedSize = AGP_DEFAULT_SIZE;
+          if(drmAgpAlloc(pSIS->drmSubFD, pSIS->agpWantedSize, 0, NULL, &pSIS->agpHandle) < 0) {
+             xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to allocate %dMB AGP memory, AGP disabled\n",
+	  	        AGP_DEFAULT_SIZE_MB);
+             drmAgpRelease(pSIS->drmSubFD);
+             break;
+	  }
+       } else {
+          drmAgpRelease(pSIS->drmSubFD);
+          break;
+       }
     }
-   
+
+    xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Allocated %dMB AGP memory\n",
+    		(int)(pSIS->agpWantedSize / (1024 * 1024)));
+
     if(drmAgpBind(pSIS->drmSubFD, pSIS->agpHandle, 0) < 0) {
-       xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] drmAgpBind failed\n");
+       xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to bind AGP memory\n");
        drmAgpFree(pSIS->drmSubFD, pSIS->agpHandle);
-       drmAgpRelease(pSIS->drmSubFD);
-       break;
+       if(pSIS->agpWantedSize > AGP_DEFAULT_SIZE) {
+          xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Retrying with %dMB\n", AGP_DEFAULT_SIZE_MB);
+          pSIS->agpWantedSize = AGP_DEFAULT_SIZE;
+          if(drmAgpAlloc(pSIS->drmSubFD, pSIS->agpWantedSize, 0, NULL, &pSIS->agpHandle) < 0) {
+	     xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to re-allocate AGP memory, AGP disabled\n");
+	     drmAgpRelease(pSIS->drmSubFD);
+             break;
+	  } else if(drmAgpBind(pSIS->drmSubFD, pSIS->agpHandle, 0) < 0) {
+	     xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to bind AGP memory again, AGP disabled\n");
+             drmAgpFree(pSIS->drmSubFD, pSIS->agpHandle);
+	     drmAgpRelease(pSIS->drmSubFD);
+             break;
+	  }
+       } else {
+          drmAgpRelease(pSIS->drmSubFD);
+          break;
+       }
     }
 
-    pSIS->agpSize = AGP_SIZE;
+    xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Bound %dMB AGP memory\n",
+	       (int)(pSIS->agpWantedSize / (1024 * 1024)));
+
+    pSIS->agpSize = pSIS->agpWantedSize;
     pSIS->agpAddr = drmAgpBase(pSIS->drmSubFD);
     /* pSIS->agpBase = */
 
     pSISDRI->agp.size = pSIS->agpSize;
-    if(drmAddMap(pSIS->drmSubFD, (drmHandle)0,
-                 pSISDRI->agp.size, DRM_AGP, 0,
-                 &pSISDRI->agp.handle) < 0) {
-       xf86DrvMsg(pScreen->myNum, X_ERROR,
-                 "[drm] Failed to map public agp area\n");
+    if(drmAddMap(pSIS->drmSubFD, (drmHandle)0, pSISDRI->agp.size, DRM_AGP, 0, &pSISDRI->agp.handle) < 0) {
+       xf86DrvMsg(pScreen->myNum, X_ERROR, "[drm] Failed to map public AGP area, AGP disabled\n");
        pSISDRI->agp.size = 0;
        break;
     }
@@ -448,7 +481,7 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
        pSISDRI->AGPVtxBufOffset = pSIS->agpVtxBufAddr - pSIS->agpAddr;
        pSISDRI->AGPVtxBufSize = pSIS->agpVtxBufSize;
 
-       drmSiSAgpInit(pSIS->drmSubFD, AGP_VTXBUF_SIZE,(AGP_SIZE - AGP_VTXBUF_SIZE));
+       drmSiSAgpInit(pSIS->drmSubFD, AGP_VTXBUF_SIZE,(pSIS->agpSize - AGP_VTXBUF_SIZE));
 #endif
     } else {
 
@@ -460,7 +493,7 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
        pSISDRI->AGPCmdBufOffset = pSIS->agpCmdBufAddr - pSIS->agpAddr;
        pSISDRI->AGPCmdBufSize = pSIS->agpCmdBufSize;
 
-       drmSiSAgpInit(pSIS->drmSubFD, AGP_CMDBUF_SIZE,(AGP_SIZE - AGP_CMDBUF_SIZE));
+       drmSiSAgpInit(pSIS->drmSubFD, AGP_CMDBUF_SIZE,(pSIS->agpSize - AGP_CMDBUF_SIZE));
     }
   }
   while(0);
@@ -473,7 +506,7 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
 
   if((drmCtlInstHandler(pSIS->drmSubFD, pSIS->irq)) != 0) {
      xf86DrvMsg(pScrn->scrnIndex, X_INFO,
-         "[drm] failure adding irq %d handler, stereo disabled\n",
+         "[drm] Failed to add IRQ %d handler, stereo disabled\n",
          pSIS->irq);
      pSIS->irqEnabled = FALSE;
   } else {
@@ -487,7 +520,7 @@ Bool SISDRIScreenInit(ScreenPtr pScreen)
      return FALSE;
   }
 
-  xf86DrvMsg(pScrn->scrnIndex, X_INFO, "[dri] visual configs initialized.\n" );
+  xf86DrvMsg(pScrn->scrnIndex, X_INFO, "[dri] Visual configs initialized.\n" );
 
   return TRUE;
 }
@@ -525,9 +558,9 @@ SISDRICloseScreen(ScreenPtr pScreen)
   if(pSIS->pVisualConfigsPriv) xfree(pSIS->pVisualConfigsPriv);
 
   if(pSIS->agpSize){
-     xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Freeing agp memory\n");
+     xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Freeing AGP memory\n");
      drmAgpFree(pSIS->drmSubFD, pSIS->agpHandle);
-     xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Releasing agp module\n");
+     xf86DrvMsg(pScreen->myNum, X_INFO, "[drm] Releasing AGP module\n");
      drmAgpRelease(pSIS->drmSubFD);
   }
 }
