@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis_vga.c,v 1.33 2003/10/30 18:53:43 twini Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/sis/sis_vga.c,v 1.39 2003/11/24 19:08:53 twini Exp $ */
 /*
  * Mode setup and basic video bridge detection
  *
@@ -884,9 +884,6 @@ SIS300Init(ScrnInfoPtr pScrn, DisplayModePtr mode)
     SISRegPtr      pReg = &pSiS->ModeReg;
     unsigned short temp;
     DisplayModePtr realmode = mode;
-#ifdef SISMERGED
-    DisplayModePtr realmode2 = NULL;
-#endif
 
     PDEBUG(xf86DrvMsgVerb(pScrn->scrnIndex, X_INFO, 4, "SIS300Init()\n"));
 
@@ -898,7 +895,6 @@ SIS300Init(ScrnInfoPtr pScrn, DisplayModePtr mode)
 #ifdef SISMERGED
     if(pSiS->MergedFB) {
        realmode = ((SiSMergedDisplayModePtr)mode->Private)->CRT1;
-       realmode2 = ((SiSMergedDisplayModePtr)mode->Private)->CRT2;
     }
 #endif
 
@@ -1001,7 +997,7 @@ SISSense30x(ScrnInfoPtr pScrn)
     unsigned char cvbs_cl, cvbs_ch;
     unsigned char vga2_bl, vga2_bh;
     unsigned char vga2_cl, vga2_ch;
-    int myflag, result=0, i, j, haveresult;
+    int myflag, result=0, i, j;
     unsigned short temp;
 
     inSISIDXREG(SISPART4,0x0d,backupP4_0d);
@@ -1043,7 +1039,7 @@ SISSense30x(ScrnInfoPtr pScrn)
 	   cvbs_bh = 0x00; cvbs_bl = 0xb3;
 	   biosflag = 2;
 	}
-	if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV)) {
+	if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_302ELV)) {
 	   vga2_bh = 0x01; vga2_bl = 0x90;
 	   svhs_bh = 0x01; svhs_bl = 0x6b;
 	   cvbs_bh = 0x01; cvbs_bl = 0x74;
@@ -1076,7 +1072,7 @@ SISSense30x(ScrnInfoPtr pScrn)
 	   else if(pSiS->VBFlags & VB_301C)   temp += 18;
 	   else if(pSiS->VBFlags & VB_301LV)  temp += 12;
 	   else if(pSiS->VBFlags & VB_302LV)  temp += 12;
-	   else if(pSiS->VBFlags & VB_301LVX) temp += 18;
+	   else if(pSiS->VBFlags & VB_302ELV) temp += 18;
 	   vga2_bh = pSiS->BIOS[temp+1]; vga2_bl = pSiS->BIOS[temp];
 	   svhs_bh = pSiS->BIOS[temp+3]; svhs_bl = pSiS->BIOS[temp+2];
 	   cvbs_bh = pSiS->BIOS[temp+5]; cvbs_bl = pSiS->BIOS[temp+4];
@@ -1086,7 +1082,7 @@ SISSense30x(ScrnInfoPtr pScrn)
 	      vga2_bh = 0x01; vga2_bl = 0x90;
 	      svhs_bh = 0x01; svhs_bl = 0x6b; /* Are these really correct for LV? */
 	      cvbs_bh = 0x01; cvbs_bl = 0x74;
-	   } else if(pSiS->VBFlags & (VB_301C | VB_301LVX)) {
+	   } else if(pSiS->VBFlags & (VB_301C | VB_302ELV)) {
 	      vga2_bh = 0x01; vga2_bl = 0x90;
 	      svhs_bh = 0x01; svhs_bl = 0x6b;
 	      cvbs_bh = 0x01; cvbs_bl = 0x10;
@@ -1101,7 +1097,7 @@ SISSense30x(ScrnInfoPtr pScrn)
 	svhs_ch = 0x04;	svhs_cl = 0x04;
 	cvbs_ch = 0x08; cvbs_cl = 0x04;
 
-	if(pSiS->VBFlags & (VB_301LV|VB_302LV)) {
+	if(pSiS->VBFlags & (VB_301LV|VB_302LV|VB_302ELV)) {
 	   vga2_bh = 0x00; vga2_bl = 0x00;
 	   vga2_ch = 0x00; vga2_cl = 0x00;
 	   svhs_ch = 0x04; svhs_cl = 0x08;
@@ -1129,7 +1125,7 @@ SISSense30x(ScrnInfoPtr pScrn)
 	   biosflag = 2;
 	}
 	
-	if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV)) {
+	if(pSiS->VBFlags & (VB_301B|VB_301C|VB_302B|VB_301LV|VB_302LV|VB_302ELV)) {
 	   if(pSiS->sishw_ext.UseROM) {
 	      if(pSiS->Chipset == PCI_CHIP_SIS330) {
 	         vga2_bh = pSiS->BIOS[0xec]; vga2_bl = pSiS->BIOS[0xeb];
@@ -1162,7 +1158,7 @@ SISSense30x(ScrnInfoPtr pScrn)
 	   }
 	}
 	
-	if(pSiS->VBFlags & (VB_301LV|VB_302LV)) {
+	if(pSiS->VBFlags & (VB_301LV|VB_302LV|VB_302ELV)) {
 	   /* TW: No VGA2 or SCART on LV bridges */
 	   vga2_bh = 0x00; vga2_bl = 0x00;
 	   vga2_ch = 0x00; vga2_cl = 0x00;
@@ -1185,7 +1181,6 @@ SISSense30x(ScrnInfoPtr pScrn)
     		vga2_bh, vga2_bl, vga2_ch, vga2_cl);
 #endif
 
-       haveresult = 0;
        for(j = 0; j < 10; j++) {
           result = 0;
           for(i = 0; i < 3; i++) {
@@ -1222,11 +1217,10 @@ SISSense30x(ScrnInfoPtr pScrn)
     andSISIDXREG(SISCR, 0x32, ~0x03);
     pSiS->postVBCR32 &= ~0x03;
 
-    if(pSiS->VBFlags & (VB_301C | VB_301LVX)) {
+    if(pSiS->VBFlags & (VB_301C | VB_302ELV)) {
        orSISIDXREG(SISPART4,0x0d,0x04);
     }
 
-    haveresult = 0;
     for(j = 0; j < 10; j++) {
        result = 0;
        for(i = 0; i < 3; i++) {
@@ -1245,7 +1239,6 @@ SISSense30x(ScrnInfoPtr pScrn)
 
     if((biosflag & 0x02) || (!(result))) {
 
-       haveresult = 0;
        for(j = 0; j < 10; j++) {
           result = 0;
           for(i = 0; i < 3; i++) {
@@ -1279,6 +1272,7 @@ SiS6326TVDelay(ScrnInfoPtr pScrn, int delay)
     for(i=0; i<delay; i++) {
     	inSISIDXREG(SISSR, 0x05, temp);
     }
+    (void)temp;
 }
 
 static int
@@ -1343,9 +1337,10 @@ void SISVGAPreInit(ScrnInfoPtr pScrn)
     int     upperlimitch, lowerlimitch;
     int     chronteltype, chrontelidreg, upperlimitvb;
     unsigned char test[3];
+    static const char *detectvb = "Detected %s video bridge (ID %d; Revision 0x%x)\n";
 #if 0
     unsigned char sr17=0;
-#endif    
+#endif
     static const char  *ChrontelTypeStr[] = {
         "7004",
 	"7005",
@@ -1402,43 +1397,31 @@ void SISVGAPreInit(ScrnInfoPtr pScrn)
 		if(temp2 == 0xff) {
 	   	   pSiS->VBFlags |= VB_302LV;
 		   pSiS->sishw_ext.ujVBChipID = VB_CHIP_302LV;
-    		   xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS302LV video bridge (ID 1; Revision 0x%x)\n",
-				temp1);
+    		   xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "SiS302LV", 1, temp1);
 		} else {
-		   pSiS->VBFlags |= VB_301LVX;
-		   pSiS->sishw_ext.ujVBChipID = VB_CHIP_301LVX;
-    		   xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS301LVX video bridge (ID 1; Revision 0x%x)\n",
-				temp1);
+		   pSiS->VBFlags |= VB_302ELV;
+		   pSiS->sishw_ext.ujVBChipID = VB_CHIP_302ELV;
+    		   xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "SiS302ELV", 1, temp1);
 		}
 	} else if(temp1 >= 0xD0) {
 	   	pSiS->VBFlags |= VB_301LV;
 		pSiS->sishw_ext.ujVBChipID = VB_CHIP_301LV;
-    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS301LV video bridge (ID 1; Revision 0x%x)\n",
-				temp1);
-	} else if(temp1 >= 0xC0) {   /* guessed */
+    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "SiS301LV", 1, temp1);
+	} else if(temp1 >= 0xC0) {
 	   	pSiS->VBFlags |= VB_301C;
 		pSiS->sishw_ext.ujVBChipID = VB_CHIP_301C;
-    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS301C video bridge (ID 1; Revision 0x%x)\n",
-				temp1);
+    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "SiS301C", 1, temp1);
 	} else if(temp1 >= 0xB0) {
 	        pSiS->VBFlags |= VB_301B;
 		pSiS->sishw_ext.ujVBChipID = VB_CHIP_301B;
 		inSISIDXREG(SISPART4, 0x23, temp2);
 		if(!(temp2 & 0x02)) pSiS->VBFlags |= VB_30xBDH;
-    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS301B%s video bridge (Revision 0x%x)\n",
-				(temp2 & 0x02) ? "" : " (DH)",
-				temp1);
+    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb,
+				(temp2 & 0x02) ? "SiS301B" : "SiS301B-DH", temp1);
 	} else {
 	        pSiS->VBFlags |= VB_301;
 		pSiS->sishw_ext.ujVBChipID = VB_CHIP_301;
-		xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS301 video bridge (Revision 0x%x)\n",
-				temp1);
+		xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "SiS301", 1, temp1);
 	}
 
 	SISSense30x(pScrn); 
@@ -1450,32 +1433,25 @@ void SISVGAPreInit(ScrnInfoPtr pScrn)
 	if(temp1 >= 0xE0) {
         	pSiS->VBFlags |= VB_302LV;
 		pSiS->sishw_ext.ujVBChipID = VB_CHIP_302LV;
-    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS302LV video bridge (ID 2; Revision 0x%x)\n",
-				temp1);
+    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "SiS302LV", 2, temp1);
 	} else if(temp1 >= 0xD0) {
         	pSiS->VBFlags |= VB_301LV;
 		pSiS->sishw_ext.ujVBChipID = VB_CHIP_301LV;
-    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS301LV video bridge (ID 2; Revision 0x%x)\n",
-				temp1);
+    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "SiS301LV", 2, temp1);
 	} else {
 	        pSiS->VBFlags |= VB_302B;
 		pSiS->sishw_ext.ujVBChipID = VB_CHIP_302B;
 		inSISIDXREG(SISPART4, 0x23, temp2);
 		if(!(temp & 0x02)) pSiS->VBFlags |= VB_30xBDH;
-    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		                "Detected SiS302B%s video bridge (Revision 0x%x)\n",
-				(temp2 & 0x02) ? "" : " (DH)",
-				temp1);
+    		xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb,
+				(temp2 & 0x02) ? "SiS302B" : "SiS302B-DH", temp1);
 	}
 
 	SISSense30x(pScrn);
 
     } else if (temp == 3) {
 
-    	xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-	           "Detected SiS303 video bridge - not supported\n");
+    	xf86DrvMsg(pScrn->scrnIndex, X_PROBED, detectvb, "unsupported SiS303", temp, 0);
 
     } else {
 
@@ -1505,7 +1481,7 @@ void SISVGAPreInit(ScrnInfoPtr pScrn)
 	if((temp >= lowerlimitlvds) && (temp <= upperlimitlvds)) {
                pSiS->VBFlags |= VB_LVDS;
     	       xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-	               "Detected LVDS transmitter (Bridge type %d)\n", temp);
+	               "Detected LVDS transmitter (External chip ID %d)\n", temp);
 	}
         if((temp >= lowerlimitch) && (temp <= upperlimitch))  {
 	    /* Set global for init301.c */
@@ -1549,7 +1525,7 @@ void SISVGAPreInit(ScrnInfoPtr pScrn)
 		   default:   temp2 = 8; pSiS->ChrontelType = CHRONTEL_701x; break;
 		}
    	        xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-	               "Detected Chrontel %s TV encoder (ID 0x%02x; bridge type %d)\n",
+	               "Detected Chrontel %s TV encoder (ID 0x%02x; chip ID %d)\n",
 		       			ChrontelTypeStr[temp2], temp1, temp);
 
 		/* Sense connected TV's */
@@ -1751,8 +1727,8 @@ void SISVGAPreInit(ScrnInfoPtr pScrn)
      */
     if(pSiS->VGAEngine == SIS_315_VGA) {
 
-       if(pSiS->VBFlags & (VB_302B | VB_301LV | VB_302LV)) {
-          if(pSiS->sisfblcda != 0xff) {	  
+       if(pSiS->VBFlags & (VB_301C | VB_302B | VB_301LV | VB_302LV | VB_302ELV)) {
+          if(pSiS->sisfblcda != 0xff) {
 	     if((pSiS->sisfblcda & 0x03) == 0x03) {
 	        pSiS->SiS_Pr->SiS_UseLCDA = TRUE;
 	        pSiS->ChipFlags |= SiSCF_UseLCDA;
@@ -1788,7 +1764,7 @@ void SISVGAPreInit(ScrnInfoPtr pScrn)
 	  }
 	  if(pSiS->ChipFlags & SiSCF_UseLCDA) {
 	     xf86DrvMsg(pScrn->scrnIndex, X_PROBED,
-		"Bridge uses LCDA for low resolution and text modes\n");
+		"BIOS uses LCDA for low resolution and text modes\n");
 	     if(pSiS->SiS_Pr->Backup == TRUE) {
 	        inSISIDXREG(SISCR,0x34,pSiS->SiS_Pr->Backup_Mode);
                 inSISIDXREG(SISPART1,0x14,pSiS->SiS_Pr->Backup_14);
