@@ -13,7 +13,7 @@
  * without express or implied warranty.
  *
  */
-/* $XFree86: xc/programs/Xserver/os/xdmcp.c,v 3.27 2003/10/02 13:30:12 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/os/xdmcp.c,v 3.29 2003/11/22 04:51:02 dawes Exp $ */
 
 #ifdef WIN32
 /* avoid conflicting definitions */
@@ -66,6 +66,11 @@
 
 #ifdef XDMCP
 #undef REQUEST
+
+#ifdef XDMCP_NO_IPV6
+#undef IPv6
+#endif
+
 #include <X11/Xdmcp.h>
 
 #define X_INCLUDE_NETDB_H
@@ -1602,7 +1607,7 @@ get_mcast_options(argc, argv, i)
     int	    argc, i;
     char    **argv;
 {
-    char *address = "ff02::1";	/* Default address until IANA assigns one */
+    char *address = XDM_DEFAULT_MCAST_ADDR6;
     int hopcount = 1;
     struct addrinfo hints;
     char portstr[6];
